@@ -2,9 +2,9 @@
 
 # Build zipfiles for ATK on Win32
 
-ZIP=/tmp/atk-1.2.0-`date +%Y%m%d`.zip
-DEVZIP=/tmp/atk-dev-1.2.0-`date +%Y%m%d`.zip
-cd /usr
+ZIP=/tmp/atk-1.2.1-`date +%Y%m%d`.zip
+DEVZIP=/tmp/atk-dev-1.2.1-`date +%Y%m%d`.zip
+cd /opt/gnome-2.0
 
 rm $ZIP
 zip -r $ZIP -@ <<EOF
