@@ -8,6 +8,11 @@
 
 G_BEGIN_DECLS
 
+/* enumerations from "atkhyperlink.h" */
+
+GType atk_hyperlink_state_flags_get_type (void);
+#define ATK_TYPE_HYPERLINK_STATE_FLAGS (atk_hyperlink_state_flags_get_type())
+
 /* enumerations from "atkobject.h" */
 
 GType atk_role_get_type (void);
